@@ -7,6 +7,7 @@ from sklearn.metrics import mean_absolute_error
 from sklearn.model_selection import KFold, ShuffleSplit
 from multiprocessing.pool import ThreadPool
 from mlni.utils import time_bar
+from joblib import dump
 
 __author__ = "Junhao Wen"
 __copyright__ = "Copyright 2019-2020 The CBICA & SBIA Lab"
@@ -156,7 +157,7 @@ class SVRAlgorithmWithRBFKernel(RegressionAlgorithm):
 
     def evaluate(self, train_index, test_index):
 
-        inner_pool = ThreadPool(self._n_threads)
+        inner_pool = ThreadPool(processes=self._n_threads)
         y_train = self._y[train_index]
 
         async_result = {}
@@ -222,6 +223,9 @@ class SVRAlgorithmWithRBFKernel(RegressionAlgorithm):
         np.savetxt(os.path.join(output_dir, 'support_vectors_indices.txt'), classifier.support_)
         np.savetxt(os.path.join(output_dir, 'intersect.txt'), classifier.intercept_)
 
+        ## save the svr instance to apply external test data
+        dump(classifier, os.path.join(output_dir, 'svr.joblib'))
+
     def save_weights(self, classifier, x, output_dir):
 
         dual_coefficients = classifier.dual_coef_
@@ -259,7 +263,7 @@ class RepeatedHoldOut(RegressionValidation):
             self._cv = list(splits.split(np.zeros(len(y)), y))
         else:
             self._cv = splits_indices
-        async_pool = ThreadPool(n_threads)
+        async_pool = ThreadPool(processes=n_threads)
         async_result = {}
 
         for i in range(self._n_iterations):
@@ -445,7 +449,7 @@ class KFoldCV(RegressionValidation):
         else:
             self._cv = splits_indices
 
-        async_pool = ThreadPool(n_threads)
+        async_pool = ThreadPool(processes=n_threads)
         async_result = {}
 
         for i in range(n_folds):
